/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CacheInformationItem.h"
#include "Debug.h"

#include <algorithm>
#include <numeric>

//__________________________________________________________________________
void CacheInformationItem::update()
{

    // check location
    if( type_ == Type::Unknown || !( location_.exists() && location_.isDirectory() ) )
    {
        itemCount_ = 0;
        size_ = 0;
        return;
    }

    QRegExp regExp( _fileRegExp() );

    // list files
    auto files = location_.listFiles( File::FilesOnly );

    // calculate item count
    itemCount_ = std::count_if( files.begin(), files.end(),
        [regExp]( const File& file )
        { return file.get().indexOf( regExp ) >= 0; } );

    // calculate total size
    size_ = std::accumulate( files.begin(), files.end(), qint64(0),
        [regExp]( qint64 size, const File& file )
        { return file.get().indexOf( regExp ) >= 0 ? size + file.fileSize() : size; } );

}

//__________________________________________________________________________
void CacheInformationItem::clear()
{

    // check location
    if( type_ == Type::Unknown || !( location_.exists() && location_.isDirectory() ) )
    {
        itemCount_ = 0;
        size_ = 0;
        return;
    }

    QRegExp regExp( _fileRegExp() );

    // list files
    auto files = location_.listFiles( File::FilesOnly );

    // erase all files matching regext
    for( const auto& file:files )
    { if( file.get().indexOf( regExp ) >= 0 ) file.remove(); }

    // update
    update();

}

//__________________________________________________________________________
QRegExp CacheInformationItem::_fileRegExp() const
{
    switch( type_ )
    {
        case Type::AlbumArt: return QRegExp( "AlbumArt_\\{\\d+\\}\\.png" );
        case Type::Lyrics: return QRegExp( "Lyrics_\\{\\d+\\}\\.txt" );
        case Type::Cddb: return QRegExp( "Cddb_\\{\\d+\\}\\.xml" );
        default: return QRegExp();
    }

}
