/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CacheInformationWidget.h"
#include "CacheInformationItem.h"

#include "CppUtil.h"
#include "Debug.h"
#include "TreeView.h"
#include "XmlOptions.h"

#include <QLayout>

//________________________________________________________
CacheInformationWidget::CacheInformationWidget( QWidget* parent ):
    QWidget( parent ),
    Counter( "CacheInformationWidget" )
{
    Debug::Throw( "CacheInformationWidget::CacheInformationWidget.\n" );

    auto vLayout = new QVBoxLayout;
    vLayout->setMargin(0);
    vLayout->setSpacing(2);
    setLayout( vLayout );

    vLayout->addWidget( list_ = new TreeView( this ) );
    list_->setModel( &model_ );
    list_->setOptionName( "CACHE_INFORMATION_LIST" );
    list_->setSelectionMode( QAbstractItemView::ContiguousSelection );
    list_->setSortingEnabled( false );

    auto items = Base::makeT<CacheInformationItem::List>( {
        CacheInformationItem( CacheInformationItem::Type::AlbumArt, tr( "Album Art" ), File( XmlOptions::get().raw( "ALBUM_ART_CACHE_DIR" ) ) ),
        CacheInformationItem( CacheInformationItem::Type::Lyrics, tr( "Lyrics" ), File( XmlOptions::get().raw( "LYRICS_CACHE_DIR" ) ) ),
        CacheInformationItem( CacheInformationItem::Type::Cddb, tr( "Audio CD Information" ), File( XmlOptions::get().raw( "CDDB_CACHE_DIR" ) ) )
    } );

    for( auto& item:items )
    { item.update(); }

    model_.set( items );
    list_->resizeColumns();

}
