#ifndef CddbQuery_h
#define CddbQuery_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "TrackInformation.h"

#include <QThread>

#if WITH_CDDB
#include <cddb/cddb.h>
#endif

#include <memory>

//* cddb query
class CddbQuery: public QThread, private Base::Counter<CddbQuery>
{

    Q_OBJECT

    public:

    //* constructor
    explicit CddbQuery( QObject* = nullptr );

    //* destructor
    ~CddbQuery() override = default;

    //*@name modifiers
    //@{

    //* set disc
    #if WITH_CDDB
    using CddbDiscPointer = std::shared_ptr<cddb_disc_t>;
    void setCddbDisc( const CddbDiscPointer& value )
    { cddbDisc_ = value; }
    #endif

    //@}

    Q_SIGNALS:

    //* tracks found
    void tracksFound( TrackInformation::List );

    protected:

    //* run
    void run() override;

    private:

    //* check connection
    /** this try connect using Udp.*/
    bool _checkConnection() const;

    /* try load tracks from disc */
    bool _fromDisc();

    /* write found tracks disc */
    void _toDisc( const TrackInformation::List& ) const;

    //* get cache filename
    File _fileName() const;

    //* cddb host
    QString host_;

    //* cddb port
    int port_ = 0;

    #if WITH_CDDB

    //* disc
    CddbDiscPointer cddbDisc_;

    #endif

};

#endif
