/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CollectionFindWidget.h"

#include "Debug.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "IconSize.h"
#include "LineEditor.h"
#include "TrackInformationFilterMenu.h"

#include <QAbstractButton>
#include <QLayout>

//____________________________________________________________
CollectionFindWidget::CollectionFindWidget( QWidget *parent ):
    QWidget( parent ),
    Counter( "CollectionFindWidget" )
{

    Debug::Throw( "CollectionFindWidget::CollectionFindWidget.\n" );

    // insert horizontal layout
    auto layout = new QHBoxLayout;
    layout->setMargin(0);
    layout->setSpacing(2);
    setLayout( layout );

    // create line editor
    editor_ = new LineEditor( this );
    editor_->setPlaceholderText( tr("Search collection") );
    layout->addWidget( editor_, 1 );

    // find toolbutton
    auto findButton = new LineEditorButton;
    findButton->setIcon( IconEngine::get( IconNames::Find ) );
    editor_->addRightWidget( findButton );

    // mask toolbutton
    auto maskButton = new QToolButton( this );
    maskButton->setIcon( IconEngine::get( IconNames::Menu ) );
    maskButton->setAutoRaise( true );
    layout->addWidget( maskButton );

    auto maskMenu = new TrackInformationFilterMenu;
    maskButton->setMenu( maskMenu );
    maskButton->setPopupMode( QToolButton::InstantPopup );
    connect( maskMenu, SIGNAL(maskChanged(TrackInformation::Mask)), SLOT(_updateMask(TrackInformation::Mask)) );

    maskButton->hide();

    // connections
    connect( findButton, SIGNAL(clicked()), SLOT(_requestSearch()) );
    connect( editor_, SIGNAL(returnPressed()), SLOT(_requestSearch()) );
    connect( &editor_->clearButton(), SIGNAL(clicked()), SLOT(_requestReset()) );

}

//____________________________________________________________
void CollectionFindWidget::_requestSearch()
{ emit requestSearchCollection( editor_->text(), mask_ ); }

//____________________________________________________________
void CollectionFindWidget::_requestReset()
{ emit requestSearchCollection( QString(), mask_ ); }
