#ifndef CoverManager_h
#define CoverManager_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "CollectionItem.h"

#include <QBasicTimer>
#include <QImage>
#include <QObject>
#include <QList>
#include <QNetworkAccessManager>
#include <QPair>
#include <QTimerEvent>
#include <QUrl>

class CoverManager: public QObject, private Base::Counter<CoverManager>
{

    Q_OBJECT

    public:

    //* constructor
    explicit CoverManager( QObject* = nullptr );

    //* get cover filename
    static File fileName( const CollectionItem& );

    using CoverPair = QPair<CollectionItem, QImage>;
    using CoverList = QList<CoverPair>;

    Q_SIGNALS:

    //* emitted when a cover is found for a given track information
    void coversFound( CoverManager::CoverList );

    public Q_SLOTS:

    //* request album
    void get( const CollectionItem& );

    protected:

    //* timer event
    void timerEvent( QTimerEvent* ) override;

    private Q_SLOTS:

    //* download cover
    void _download( const CollectionItem&, const QUrl& );

    //* save image to disk and cache
    void _save( const CollectionItem&, const QImage& );

    private:

    //* get cover from cache. Returns true on success
    bool _fromDisk( const CollectionItem& );

    //* delayed cover found
    void _delayedCoverFound( const CollectionItem&, const QImage& );

    //* network access manager
    QNetworkAccessManager* networkAccessManager_ = nullptr;

    //* empty image
    QImage empty_;

    //* timer
    QBasicTimer timer_;

    //* pending covers
    CoverList pendingCovers_;

};

#endif
