#ifndef CoverManager_p_h
#define CoverManager_p_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CollectionItem.h"
#include "Counter.h"
#include "File.h"
#include "ObjectDeleter.h"

#include <QObject>
#include <QNetworkReply>
#include <QUrl>

#include <memory>

namespace Private
{

    class CoverJob: public QObject, private Base::Counter<CoverJob>
    {

        Q_OBJECT

        public:

        //* constructor
        explicit CoverJob( QNetworkReply* );

        //* destructor
        ~CoverJob() override;

        Q_SIGNALS:

        //* finished
        void finished();

        protected Q_SLOTS:

        //* finished
        virtual void _finished() = 0;

        protected:

        //* true if network reply is valid
        bool _hasNetworkReply() const
        { return static_cast<bool>(networkReply_); }

        //* accessor
        QNetworkReply& _networkReply() const
        { return *networkReply_; }

        private Q_SLOTS:

        //* abort job
        void _abort();

        private:

        //* network reply
        std::unique_ptr<QNetworkReply, Base::ObjectDeleter> networkReply_;

    };

    //* used to get cover url from last.fm
    class CoverLocationJob: public CoverJob
    {

        Q_OBJECT

        public:

        //* constructor
        explicit CoverLocationJob( const CollectionItem&, QNetworkReply* );

        Q_SIGNALS:

        //* emitted when a cover is found
        void coverFound( CollectionItem, QUrl );

        protected Q_SLOTS:

        //* finished
        void _finished() override;

        private:

        //* destination file
        CollectionItem collectionItem_;

    };

    //* used to downolad covers from given location
    class CoverDownloadJob: public CoverJob
    {

        Q_OBJECT

        public:

        //* constructor
        explicit CoverDownloadJob( const CollectionItem&, QNetworkReply* );

        Q_SIGNALS:

        //* emitted when a cover is found
        void coverFound( CollectionItem, QImage );

        protected Q_SLOTS:

        //* finished
        void _finished() override;

        private:

        //* track information
        CollectionItem collectionItem_;

    };
}

#endif
