#ifndef CoreAdaptor_h
#define CoreAdaptor_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "MainWindow.h"

#include <QDBusAbstractAdaptor>

namespace DBus
    {
    class CoreAdaptor: public QDBusAbstractAdaptor, private Base::Counter<CoreAdaptor>
    {

        Q_OBJECT
        Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2")

        public:

        //* constructor
        explicit CoreAdaptor( MainWindow* );

        //* parent
        inline MainWindow* parent() const
        { return static_cast<MainWindow*>( QObject::parent() ); }

        Q_PROPERTY( bool CanQuit READ canQuit )
        bool canQuit() const
        { return true; }

        Q_PROPERTY( bool CanRaise READ canRaise )
        bool canRaise() const
        { return true; }

        Q_PROPERTY( bool CanSetFullscreen READ canSetFullscreen )
        bool canSetFullscreen() const
        { return false; }

        Q_PROPERTY( QString DesktopEntry READ desktopEntry )
        QString desktopEntry() const
        { return QLatin1String( "musicbox" ); }

        Q_PROPERTY( bool Fullscreen READ fullscreen WRITE setFullscreen )
        bool fullscreen() const
        { return false; }

        void setFullscreen( bool value )
        {}

        Q_PROPERTY( bool HasTrackList READ hasTrackList )
        bool hasTrackList() const
        { return true; }

        Q_PROPERTY( QString Identity READ identity )
        QString identity() const
        { return QLatin1String( "Musicbox" ); }

        Q_PROPERTY( QStringList SupportedMimeTypes READ supportedMimeTypes )
        QStringList supportedMimeTypes() const
        { return QStringList(); }

        Q_PROPERTY( QStringList SupportedUriSchemes READ supportedUriSchemes )
        QStringList supportedUriSchemes() const
        { return QStringList(); }

        public Q_SLOTS:
        void Quit();
        void Raise();

    };

}

#endif
