#ifndef FileSystemWidget_h
#define FileSystemWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseFileSystemWidget.h"
#include "File.h"

#include <QAction>

class FileSystemWidget: public BaseFileSystemWidget
{

    Q_OBJECT

    public:

    //* constructor
    explicit FileSystemWidget( QWidget* = nullptr );

    Q_SIGNALS:

    //* add items to playlist
    void requestAddToPlaylist( const File::List& );

    //* replace playlist
    void requestReplacePlaylist( const File::List& );

    #if WITH_TAGLIB
    //* request tag edition
    void requestEditTags( const File::List& );
    #endif

    protected Q_SLOTS:

    //* update actions
    void _updateActions() override;

    private Q_SLOTS:

    //* add to playlist
    void _addSelectionToPlaylist();

    //* replace playlist
    void _replacePlaylist();

    #if WITH_TAGLIB
    //* edit tags
    void _editTags();
    #endif

    private:

    //* install actions
    void _installActions();

    //* get (recursive) file list from selection
    File::List _selectedFiles() const;

    //*@name actions
    //@{

    //* add to playlist
    QAction* addToPlaylistAction_ = nullptr;

    //* replace playlist
    QAction* replacePlaylistAction_ = nullptr;

    #if WITH_TAGLIB
    //* edit tags
    QAction* editTagsAction_ = nullptr;
    #endif

    //@}
};

#endif
