/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ListNotificationWidget.h"

#include "Color.h"
#include "Debug.h"

#include <QPainter>

//____________________________________________________
ListNotificationWidget::ListNotificationWidget( const QString& text, QWidget* parent ):
    QLabel( text, parent ),
    Counter( "ListNotificationWidget" )
{
    Debug::Throw( "ListNotificationWidget::ListNotificationWidget.\n" );

    setAttribute(Qt::WA_OpaquePaintEvent, false);
    setFocusPolicy(Qt::NoFocus);
    setAttribute(Qt::WA_TransparentForMouseEvents, true);
    setContextMenuPolicy(Qt::NoContextMenu);

    setAlignment( Qt::AlignCenter );
    setForegroundRole( QPalette::WindowText );
    setBackgroundRole( QPalette::Window );
    setMargin( Margin );

    if( parent )
    {
        parent->installEventFilter( this );
        adjustSize();
        setGeometry( Margin, Margin,
            parent->width() - 2*Margin,
            height() );
    }

}

//____________________________________________________
bool ListNotificationWidget::eventFilter( QObject* object, QEvent* event )
{
    if( object == parentWidget() )
    {
        switch( event->type() )
        {
            case QEvent::Resize:
            {
                setGeometry( Margin, Margin,
                    parentWidget()->width() - 2*Margin,
                    height() );
                break;
            }

            default:
            break;
        }

    }

    return QLabel::eventFilter( object, event );

}

//_____________________________________________________________
void ListNotificationWidget::paintEvent( QPaintEvent* event )
{


    if( text().isEmpty() ) return;

    QPainter painter( this );
    painter.setClipRegion( event->region() );
    painter.setRenderHints( QPainter::Antialiasing );
    painter.setPen( Base::Color( palette().color( foregroundRole() ) ).merged( palette().color( backgroundRole() ), 0.3 ).get() );
    painter.setBrush( palette().color( backgroundRole() ) );
    painter.drawRect( QRectF( rect() ).adjusted( 0.5, 0.5, -0.5, -0.5 ) );
    painter.end();

    QLabel::paintEvent( event );

}

