#ifndef LyricsInformation_h
#define LyricsInformation_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"

#include <QDomElement>
#include <QDomDocument>
#include <QString>
#include <QUrl>

class LyricsInformation: private Base::Counter<LyricsInformation>
{

    public:

    //* default constructor
    explicit LyricsInformation(): Counter( "LyricsInformation" )
    {}

    //* constructor from dom
    explicit LyricsInformation( const QDomElement& );

    //*@name accessors
    //@{

    //* dom element
    QDomElement domElement( QDomDocument& ) const;

    //* artist
    const QString& artist() const
    { return artist_; }

    //* title
    const QString& title() const
    { return title_; }

    //* provider
    const QString& provider() const
    { return provider_; }

    //* lyrics
    const QString& lyrics() const
    { return lyrics_; }

    //* validity
    bool isValid() const
    { return !lyrics_.isEmpty(); }

    //@}

    //*@name modifiers
    //@{

    //* artist
    void setArtist( const QString& value )
    { artist_ = value; }

    //* title
    void setTitle( const QString& value )
    { title_ = value; }

    //* provider
    void setProvider( const QString& value )
    { provider_ = value; }

    //* url
    void setUrl( const QUrl& value )
    { url_ = value; }

    //* lyrics
    void setLyrics( const QString& value )
    { lyrics_ = value; }

    //@}

    private:

    QString artist_;
    QString title_;
    QString provider_;
    QUrl url_;
    QString lyrics_;

};
#endif
