#ifndef LyricsManager_h
#define LyricsManager_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseLyricsProvider.h"
#include "Counter.h"
#include "LyricsInformation.h"
#include "TrackInformation.h"

#include <QHash>
#include <QNetworkAccessManager>


class LyricsManager: public QObject, private Base::Counter<LyricsManager>
{

    Q_OBJECT

    public:

    //* constructor
    explicit LyricsManager( QObject* = nullptr );

    //*@name accessors
    //@{

    //* lytics filename
    static File fileName( const TrackInformation& );

    //* providers
    const BaseLyricsProvider::List& providers() const
    { return lyricsProviderList_; }

    //@}

    Q_SIGNALS:

    //* lyrics found
    void lyricsFound( TrackInformation, LyricsInformation );

    //* lyrics not found
    void lyricsNotFound( TrackInformation );

    public Q_SLOTS:

    //* request album
    void get( const TrackInformation& );

    private Q_SLOTS:

    //* process lyrics found
    void _lyricsFound( const TrackInformation&, const LyricsInformation& );

    //* process lyrics not found
    void _lyricsNotFound( const TrackInformation& );

    private:

    void _addLyricsProvider( BaseLyricsProvider* );

    //* get cover from cache. Returns true on success
    bool _fromDisk( const TrackInformation& );

    //* network access manager
    QNetworkAccessManager* networkAccessManager_ = nullptr;

    //* list of lyrics provider
    BaseLyricsProvider::List lyricsProviderList_;

    //* hash track information and index in providers list
    using TrackInformationHash = QHash<uint,int>;
    TrackInformationHash trackInformationHash_;

};

#endif
