#ifndef LyricsWidget_h
#define LyricsWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "LyricsInformation.h"
#include "TrackInformation.h"

#include <QAction>

#include <QTextBlockFormat>
#include <QTextCharFormat>

class TextEditor;

class LyricsWidget: public QWidget, private Base::Counter<LyricsWidget>
{

    Q_OBJECT

    public:

    //* constructor
    explicit LyricsWidget( QWidget* = nullptr );

    //*@name modifiers
    //@{

    void setTrackInformation( const TrackInformation& );

    //@}

    Q_SIGNALS:

    //* request lyrics
    void requestLyrics( TrackInformation );

    public Q_SLOTS:

    //* request lyrics
    void requestLyrics();

    //* lyrics found
    void lyricsFound( const TrackInformation&, const LyricsInformation& );

    //* no lyrics found
    void lyricsNotFound( const TrackInformation& );

    private:

    //* install actions
    void _installActions();

    //* true if current track information is valid
    bool _trackInformationIsValid() const;

    //* write header
    void _writeHeader();

    //* write lyrics
    void _writeLyrics( const LyricsInformation& );

    //* write no lyrics
    void _writeNoLyrics();

    //* write provider
    void _writeProvider( const LyricsInformation& );

    //* default block format
    QTextBlockFormat defaultBlockFormat_;

    //* default char format
    QTextCharFormat defaultCharFormat_;

    //* bold char format
    QTextCharFormat boldCharFormat_;

    //* italic char format
    QTextCharFormat italicCharFormat_;

    //* text editor
    TextEditor* editor_ = nullptr;

    //* current track information
    TrackInformation trackInformation_;

    //*@name actions
    //@{

    QAction* updateAction_ = nullptr;

    //@}

};

#endif
