#ifndef MpdServerConfiguration_h
#define MpdServerConfiguration_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "File.h"
#include "Counter.h"

namespace Mpd
{

    //* mpd server configuration
    class ServerConfiguration: private Base::Counter<ServerConfiguration>
    {

        public:

        //* constructor
        explicit ServerConfiguration():
            Counter( "Mpd::ServerConfiguration" )
        {}

        //* construct from options
        static ServerConfiguration fromOptions();

        //*@name accessors
        //@{

        //* host
        const QString& host() const
        { return host_; }

        //* port
        int port() const
        { return port_; }

        //* db file
        const File& dbFile() const
        { return dbFile_; }

        //* pid file
        const File& pidFile() const
        { return pidFile_; }

        //* music directory
        const File& musicDirectory() const
        { return musicDirectory_; }

        //* true if use Tcp sockets
        bool useTcpSocket() const
        { return useTcpSocket_; }

        //@}

        //*@name modifiers
        //@{

        //* make sure relevant directories exist
        void createDirectories() const;

        //* write configuration to specified file, returns true on success
        bool write( const File& ) const;

        //* music directory
        void setMusicDirectory( const File& value )
        { musicDirectory_ = value; }

        //* playlist directory
        void setPlaylistDirectory( const File& value )
        { playlistDirectory_ = value; }

        //* sticker file
        void setStickerFile( const File& value )
        { stickerFile_ = value; }

        //* host
        void setHost( const QString& value )
        { host_ = value; }

        //* port
        void setPort( int value )
        { port_ = value; }

        //* db file
        void setDbFile( const File& value )
        { dbFile_ = value; }

        //* pid file
        void setpidFile( const File& value )
        { pidFile_ = value; }

        //* state file
        void setstateFile( const File& value )
        { stateFile_ = value; }

        //* log file
        void setlogFile( const File& value )
        { logFile_ = value; }

        //* pulse audio
        #if !defined(Q_OS_WIN)
        void setUsePulseAudio( bool value )
        { usePulseAudio_ = value; }
        #endif

        //@}

        private:

        File musicDirectory_;
        File playlistDirectory_;
        File stickerFile_;

        QString host_;
        int port_ = 6600;

        File dbFile_;
        File pidFile_;
        File stateFile_;
        File logFile_;

        bool useTcpSocket_ = false;

        #if !defined(Q_OS_WIN)
        bool usePulseAudio_ = true;
        #endif

        friend bool operator == ( const ServerConfiguration& lhs, const ServerConfiguration& rhs )
        {
            return
                lhs.musicDirectory_ == rhs.musicDirectory_
                && lhs.playlistDirectory_ == rhs.playlistDirectory_
                && lhs.stickerFile_ == rhs.stickerFile_
                && lhs.host_ == rhs.host_
                && lhs.port_ == rhs.port_
                && lhs.dbFile_ == rhs.dbFile_
                && lhs.pidFile_ == rhs.pidFile_
                && lhs.stateFile_ == rhs.stateFile_
                && lhs.logFile_ == rhs.logFile_
                && lhs.useTcpSocket_ == rhs.useTcpSocket_
                #if !defined(Q_OS_WIN)
                && lhs.usePulseAudio_ == rhs.usePulseAudio_
                #endif
                ;
        }

    };

}

#endif
