/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MpdTcpSocket.h"

#include "MpdServerConfiguration.h"

namespace Mpd
{

    //_______________________________________________________
    TcpSocket::TcpSocket( QObject* parent ):
        BaseSocket( parent ),
        Counter( "Mpd::TcpSocket" ),
        socket_( new QTcpSocket( this ) )
    {
        connect( socket_, SIGNAL(error(QAbstractSocket::SocketError)), this, SIGNAL(error()) );
        connect( socket_, SIGNAL(disconnected()), this, SIGNAL(disconnected()) );
        connect( socket_, SIGNAL(readyRead()), this, SIGNAL(readyRead()) );
    }

    //_______________________________________________________
    bool TcpSocket::connect( const ServerConfiguration& serverConfiguration )
    {
        socket_->connectToHost( serverConfiguration.host(), serverConfiguration.port() );
        return socket_->waitForConnected();
    }

    //_______________________________________________________
    void TcpSocket::disconnect()
    {
        socket_->disconnectFromHost();
        if( socket_->state() != QAbstractSocket::UnconnectedState )
        { socket_->waitForDisconnected(); }
    }

}
