#ifndef PlaylistDelegate_h
#define PlaylistDelegate_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "IconSize.h"

#include <QAbstractItemDelegate>

// forward declaration
class TrackInformationModel;

//* item delegate
class PlaylistDelegate : public QAbstractItemDelegate, private Base::Counter<PlaylistDelegate>
{

    Q_OBJECT

    public:

    //* constructor
    explicit PlaylistDelegate( QObject* = nullptr );

    //* paint
    void paint( QPainter*, const QStyleOptionViewItem&, const QModelIndex& ) const override;

    //* size
    QSize sizeHint( const QStyleOptionViewItem&, const QModelIndex& ) const override;

    //* true if passed position is in album rect
    bool isInAlbum( const QPoint&, const QStyleOptionViewItem&, const QModelIndex& ) const;

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    private:

    //* true if album needs to also be shown
    bool _needsAlbum( const TrackInformationModel&, const QModelIndex& ) const;

    //* render text
    void _renderTextLeftRight( QPainter*, const QStyleOptionViewItem&, const QString&, const QString& ) const;

    //* margin
    int margin_ = 4;

    //* spacing
    int spacing_ = 4;

    //* cover size
    int coverSize_ = IconSize::Large;

    //* icon size
    int iconSize_ = IconSize::Small;

};

#endif
