/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "PlaylistFindWidget.h"

#include "IconEngine.h"
#include "IconNames.h"

#include <QLayout>
#include <QToolButton>

//________________________________________________________________________
PlaylistFindWidget::PlaylistFindWidget( QWidget* parent ):
    AbstractFindWidget( parent ),
    Counter( "PlaylistFindWidget" )
{

    Debug::Throw( "PlaylistFindWidget::PlaylistFindWidget.\n" );

    // layout
    auto layout = new QHBoxLayout;
    layout->setMargin(0);
    layout->setSpacing(2);
    setLayout( layout );

    layout->addWidget( editor_ = new LineEditor( this ) );
    editor_->setPlaceholderText( tr("Search playlist") );

    // find toolbutton
    auto findButton = new LineEditorButton;
    findButton->setIcon( IconEngine::get( IconNames::Find ) );
    editor_->addRightWidget( findButton );

    connect( findButton, SIGNAL(pressed()), SLOT(_find()) );

    connect( editor_, SIGNAL(cleared()), SLOT(matchFound()) );
    connect( editor_, SIGNAL(returnPressed()), SLOT(_find()) );
    connect( editor_, SIGNAL(textChanged(QString)), SLOT(_updateButtons(QString)) );
    connect( editor_, SIGNAL(textChanged(QString)), SLOT(_findNoIncrement()) );

    // Find next button
    QToolButton* button;
    layout->addWidget( button = new QToolButton( this ) );
    button->setIcon( IconEngine::get( IconNames::FindNext ) );
    button->setAutoRaise( true );
    connect( button, SIGNAL(clicked()), SLOT(_findNext()) );
    _addDisabledButton( button );
    findNextButton_ = button;

    // Find next button
    layout->addWidget( button = new QToolButton( this ) );
    button->setIcon( IconEngine::get( IconNames::FindPrevious ) );
    button->setAutoRaise( true );
    connect( button, SIGNAL(clicked()), SLOT(_findPrevious()) );
    _addDisabledButton( button );
    findPreviousButton_ = button;

    // close button
    layout->addWidget( button = new QToolButton( this ) );
    button->setAutoRaise( true );
    button->setIcon( IconEngine::get( IconNames::DialogClose ) );
    connect( button, SIGNAL(clicked()), this,  SLOT(hide()) );
    closeButton_ = button;

}


//________________________________________________________________________
TextSelection PlaylistFindWidget::selection( bool noIncrement ) const
{
    TextSelection out( editor_->text() );
    out.setFlag( TextSelection::Backward, findBackward_ );
    out.setFlag( TextSelection::CaseSensitive, false );
    out.setFlag( TextSelection::EntireWord, false );
    out.setFlag( TextSelection::RegExp, false );
    out.setFlag( TextSelection::NoIncrement, noIncrement );
    return out;
}

//________________________________________________________________________
void PlaylistFindWidget::setText( const QString& text )
{
    editor_->setText( text );
    editor_->selectAll();
}


//________________________________________________________________________
void PlaylistFindWidget::matchFound()
{}

//________________________________________________________________________
void PlaylistFindWidget::noMatchFound()
{}

//________________________________________________________________________
void PlaylistFindWidget::synchronize()
{}

//________________________________________________________________________
void PlaylistFindWidget::_updateButtons( const QString& text )
{
    Debug::Throw( "PlaylistFindWidget::_updateButtons.\n" );

    const bool enabled( !( text.isEmpty() ) );
    for( const auto& button:buttons_ )
    { button->setEnabled( enabled ); }

}


//________________________________________________________________________
void PlaylistFindWidget::_addDisabledButton( QAbstractButton* button )
{
    Debug::Throw( "PlaylistFindWidget::_addDisabledButton.\n" );
    buttons_.append( button );
    _updateButtons();
}


