#ifndef StoredPlaylistWidget_h
#define StoredPlaylistWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "StoredPlaylistItem.h"
#include "StoredPlaylistModel.h"

#include <QAction>
#include <QLabel>
#include <QWidget>

class ScrollBarMonitor;
class StoredPlaylistView;
class ToolTipWidget;

class StoredPlaylistWidget: public QWidget, private Base::Counter<StoredPlaylistWidget>
{

    Q_OBJECT

    public:

    //* constructor
    explicit StoredPlaylistWidget( QWidget* = nullptr );

    //*@name accessors
    //@{

    //* list
    StoredPlaylistView& list() const
    { return *list_; }

    //* model
    const StoredPlaylistModel& model() const
    { return model_; }

    //* list of expanded items
    StoredPlaylistItem::List expandedItems() const;

    //* tooltip widget
    ToolTipWidget& toolTipWidget() const
    { return *toolTipWidget_; }

    //@}

    //*@name modifiers
    //@{

    //* model
    StoredPlaylistModel& model()
    { return model_; }

    //* split tracks by playlists and update
    void updatePlaylists( const StoredPlaylistItem::List& );

    //* save expanded items
    void saveExpandedItems();

    //* restore
    void restoreExpandedItems();

    //* show notification
    void showNotification()
    { notificationWidget_->show(); }

    //* hide notification
    void hideNotification()
    { notificationWidget_->hide(); }

    //* lock
    void lock();

    //* unlock
    void unlock();

    //@}

    Q_SIGNALS:

    //* request albums matching artist
    void requestTracks( const StoredPlaylistItem& );

    //* add items to playlist
    void requestAddToPlaylist( const StoredPlaylistItem::List& );

    //* replace playlist
    void requestReplacePlaylist( const StoredPlaylistItem::List& );

    //* rename playlist
    void requestRenamePlaylist( const StoredPlaylistItem&, const QString& );

    //* request export playlist
    void requestExportPlaylist( const StoredPlaylistItem& );

    //* delete items
    void requestDeleteItems( const StoredPlaylistItem::List& );


    private Q_SLOTS:

    //* index activated
    void _itemActivated( const QModelIndex& );

    //* index exmapnded
    void _itemExpanded( const QModelIndex& );

    //* update actions
    void _updateActions();

    //* add to playlist
    void _addSelectionToPlaylist();

    //* replace playlist
    void _replacePlaylist();

    //* rename playlist
    void _renamePlaylist();

    //* delete tracks
    void _deleteItems();

    //* export playlist
    void _exportPlaylist();

    //* show tooltip
    void _showToolTip( const QModelIndex& );

    private:

    //* actions
    void _installActions();

    //* locked
    /** prevents track requests to be sent */
    bool locked_ = false;

    //* treeview
    StoredPlaylistView* list_ = nullptr;

    //* scrollbar monitor
    ScrollBarMonitor* scrollBarMonitor_ = nullptr;

    //* notification
    QLabel* notificationWidget_ = nullptr;

    //* model
    StoredPlaylistModel model_;

    //* expanded items
    StoredPlaylistItem::List expandedItems_;

    //* tooltip widget
    ToolTipWidget* toolTipWidget_ = nullptr;

    //*@name actions
    //@{

    //* add to playlist
    QAction* addToPlaylistAction_ = nullptr;

    //* replace playlist
    QAction* replacePlaylistAction_ = nullptr;

    //* rename playlist
    QAction* renamePlaylistAction_ = nullptr;

    //* delete tracks/playlists
    QAction* deleteItemAction_ = nullptr;

    //* export playlist
    QAction* exportPlaylistAction_ = nullptr;

    //@}

};

#endif
