#ifndef SystemTrayIcon_h
#define SystemTrayIcon_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"

#include <QIcon>
#include <QSystemTrayIcon>
#include <QMenu>

#include <memory>

namespace Svg
{
    class SvgPlasmaInterface;
}

//* application system tray icon
class SystemTrayIcon: public QSystemTrayIcon, private Base::Counter<SystemTrayIcon>
{

    Q_OBJECT;

    public:

    //* constructor
    explicit SystemTrayIcon( QObject* = nullptr );

    //* destructor
    ~SystemTrayIcon() override;

    private Q_SLOTS:

    //* configuration
    void _updateConfiguration();

    //* icons
    void _reloadIcon();

    private:

    //* true if reload is needed on palette change
    bool _needsReloadOnPaletteChange() const;

    //* connected icon
    QIcon icon_;

    //* plasma interface
    std::unique_ptr<Svg::SvgPlasmaInterface> plasmaInterface_;

};

#endif
