#ifndef ToolTipWidget_h
#define ToolTipWidget_h

/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseToolTipWidget.h"
#include "CollectionItem.h"
#include "CoverManager.h"

#include <QIcon>
#include <QFrame>
#include <QLabel>

class GridLayoutItem;

class ToolTipWidget: public BaseToolTipWidget
{

    Q_OBJECT

    public:

    //* constructor
    explicit ToolTipWidget( QWidget* = nullptr );

    //* mask
    void setPixmapSize( int value )
    {
        if( pixmapSize_ == value ) return;
        pixmapSize_ = value;
        _reload();
    }

    //* information mask
    enum Type
    {
        None = 0,
        Artist = 1<<0,
        Album = 1 << 1,
        Title = 1 << 2,
        Year = 1 << 3,
        Disc = 1 << 4,
        Track = 1 << 5,
        Duration = 1 << 6,
        Default = Artist|Album|Title|Year|Disc|Duration
    };

    Q_DECLARE_FLAGS(Types, Type)

    //* mask
    void setMask( ToolTipWidget::Types value )
    {
        if( mask_ == value ) return;
        mask_ = value;
        _reload();
    }

    public Q_SLOTS:

    //* update icon
    bool updateCover( const CoverManager::CoverList& );

    protected:

    //* reload
    virtual void _reload() = 0;

    //* update icon
    virtual bool _updateCover( const CollectionItem&, const QImage& ) = 0;

    //* pixmap size
    int _pixmapSize() const
    { return pixmapSize_; }

    //* mask
    Types _mask() const
    { return mask_; }

    //* icon
    const QIcon& _icon() const
    { return icon_; }

    //* icon
    void _setIcon( const QIcon& icon )
    { icon_ = icon; }

    //* icon label
    QLabel& _iconLabel() const
    { return *iconLabel_; }

    GridLayoutItem& _artistItem() const
    { return *artistItem_; }

    GridLayoutItem& _albumItem() const
    { return *albumItem_; }

    GridLayoutItem& _titleItem() const
    { return *titleItem_; }

    GridLayoutItem& _yearItem() const
    { return *yearItem_; }

    GridLayoutItem& _discItem() const
    { return *discItem_; }

    GridLayoutItem& _trackItem() const
    { return *trackItem_; }

    GridLayoutItem& _durationItem() const
    { return *durationItem_; }

    private Q_SLOTS:

    //* update configuration
    void _updateConfiguration();

    private:

    //* pixmap size
    int pixmapSize_ = 96;

    //* information mask
    Types mask_ = Default;

    //* local icon copy
    QIcon icon_;

    //* icon label
    QLabel* iconLabel_ = nullptr;

    //*@name items
    //@{
    GridLayoutItem* artistItem_ = nullptr;
    GridLayoutItem* albumItem_ = nullptr;
    GridLayoutItem* titleItem_ = nullptr;
    GridLayoutItem* yearItem_ = nullptr;
    GridLayoutItem* discItem_ = nullptr;
    GridLayoutItem* trackItem_ = nullptr;
    GridLayoutItem* durationItem_ = nullptr;
    //@}

};

Q_DECLARE_OPERATORS_FOR_FLAGS( ToolTipWidget::Types )

#endif
