/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TrackInformationFilterMenu.h"

#include "CppUtil.h"
#include "Debug.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <numeric>

//____________________________________________________________________
TrackInformationFilterMenu::TrackInformationFilterMenu( QWidget* parent ):
    QMenu( parent ),
    Counter( "TrackInformationFilterMenu" )
{

    Debug::Throw( "TrackInformationFilterMenu::TrackInformationFilterMenu.\n" );
    actions_ = Base::makeT<ActionMap>(
    {
        { addAction( tr( "Artist" ) ), TrackInformation::Artist },
        { addAction( tr( "Album" ) ), TrackInformation::Album },
        { addAction( tr( "Title" ) ), TrackInformation::Title }
    } );

    // mark all actions as checkable and connect
    for( auto&& iter = actions_.begin(); iter != actions_.end(); ++iter )
    {
        iter.key()->setCheckable( true );
        connect( iter.key(), SIGNAL(toggled(bool)), SLOT(_maskChanged()) );
    }

    //* configuration
    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
    _updateConfiguration();

}

//___________________________________________________________________
TrackInformation::Mask TrackInformationFilterMenu::mask() const
{
    Debug::Throw( "TrackInformationFilterMenu::mask.\n" );
    TrackInformation::Mask out = TrackInformation::None;
    for( auto&& iter = actions_.begin(); iter != actions_.end(); ++iter )
    { if( iter.key()->isChecked() ) out |= iter.value(); }

    return out;
}

//___________________________________________________________________
void TrackInformationFilterMenu::_updateConfiguration()
{
    Debug::Throw( "TrackInformationFilterMenu::_updateConfiguration.\n" );
    _setMask( static_cast<TrackInformation::Mask>( XmlOptions::get().get<int>("TRACK_INFORMATION_FILTER") ) );
}

//___________________________________________________________________
void TrackInformationFilterMenu::_maskChanged()
{
    Debug::Throw( "TrackInformationFilterMenu::_maskChanged.\n" );
    const auto mask( this->mask() );
    XmlOptions::get().set<int>( "TRACK_INFORMATION_FILTER", mask );
    emit maskChanged( mask );
}

//___________________________________________________________________
void TrackInformationFilterMenu::_setMask( TrackInformation::Mask mask )
{
    for( auto&& iter = actions_.begin(); iter != actions_.end(); ++iter )
    { iter.key()->setChecked( mask&iter.value() ); }
}
