/******************************************************************************
*
* Copyright (C) 2017 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TrackInformationToolTipWidget.h"

#include "CustomPixmap.h"
#include "GridLayoutItem.h"

//_______________________________________________________
void TrackInformationToolTipWidget::setTrackInformation( const TrackInformation& trackInformation, const QIcon& icon )
{
    Debug::Throw( "TrackInformationToolTipWidget::setRecord.\n" );

    // local storage
    _setIcon( icon );
    trackInformation_ = trackInformation;

    // update icon
    if( !icon.isNull() )
    {

        // get pixmap
        CustomPixmap pixmap( icon.pixmap( QSize( _pixmapSize(), _pixmapSize() ) ) );
        _iconLabel().setPixmap( pixmap );
        _iconLabel().show();

    } else _iconLabel().hide();

    // artist
    if( _mask()&Artist )
    {

        _artistItem().setText( trackInformation.artist().isEmpty() ? TrackInformation::UnknownArtist:trackInformation.artist() );

    } else _artistItem().hide();

    // album
    if( _mask()&Album)
    {

        _albumItem().setText( trackInformation.album().isEmpty() ? TrackInformation::UnknownAlbum:trackInformation.album() );

    } else _albumItem().hide();

    // title
    if( _mask()&Title )
    {

        _titleItem().setText( trackInformation.titleOrFile() );

    } else _titleItem().hide();

    // year
    if( (_mask()&Year) && trackInformation.year() > 0 )
    {

        _yearItem().setText( QString::number( trackInformation.year() ) );

    } else _yearItem().hide();

    // track
    if( (_mask()&Track) && trackInformation.track() > 0 )
    {

        _trackItem().setText( QString::number( trackInformation.track() ) );

    } else _trackItem().hide();

    // track
    if( (_mask()&Disc) && trackInformation.disc() > 0 )
    {

        _discItem().setText( QString::number( trackInformation.disc() ) );

    } else _discItem().hide();

    // duration
    if( (_mask()&Duration) && trackInformation.duration() > 0 )
    {

        _durationItem().setText( trackInformation.durationString() );

    } else _durationItem().hide();

    adjustSize();

}

//_____________________________________________
bool TrackInformationToolTipWidget::_updateCover( const CollectionItem& item, const QImage& image )
{
    if( isVisible() && trackInformation_.artist() == item.artist() && trackInformation_.album() == item.album() && !image.isNull() )
    {

        _setIcon( QIcon( QPixmap::fromImage( image ) ) );
        _reload();
        return true;

    } else return false;

}

